@@ -24,21 +24,21 @@ __all__ = (
     "ArtworkTypeDef",
     "AudioCodecOptionsTypeDef",
     "AudioParametersTypeDef",
-    "CancelJobRequestTypeDef",
+    "CancelJobRequestRequestTypeDef",
     "CaptionFormatTypeDef",
     "CaptionSourceTypeDef",
     "CaptionsTypeDef",
     "ClipTypeDef",
     "CreateJobOutputTypeDef",
     "CreateJobPlaylistTypeDef",
-    "CreateJobRequestTypeDef",
-    "CreateJobResponseResponseTypeDef",
-    "CreatePipelineRequestTypeDef",
-    "CreatePipelineResponseResponseTypeDef",
-    "CreatePresetRequestTypeDef",
-    "CreatePresetResponseResponseTypeDef",
-    "DeletePipelineRequestTypeDef",
-    "DeletePresetRequestTypeDef",
+    "CreateJobRequestRequestTypeDef",
+    "CreateJobResponseTypeDef",
+    "CreatePipelineRequestRequestTypeDef",
+    "CreatePipelineResponseTypeDef",
+    "CreatePresetRequestRequestTypeDef",
+    "CreatePresetResponseTypeDef",
+    "DeletePipelineRequestRequestTypeDef",
+    "DeletePresetRequestRequestTypeDef",
     "DetectedPropertiesTypeDef",
     "EncryptionTypeDef",
     "HlsContentProtectionTypeDef",
@@ -48,14 +48,14 @@ __all__ = (
     "JobOutputTypeDef",
     "JobTypeDef",
     "JobWatermarkTypeDef",
-    "ListJobsByPipelineRequestTypeDef",
-    "ListJobsByPipelineResponseResponseTypeDef",
-    "ListJobsByStatusRequestTypeDef",
-    "ListJobsByStatusResponseResponseTypeDef",
-    "ListPipelinesRequestTypeDef",
-    "ListPipelinesResponseResponseTypeDef",
-    "ListPresetsRequestTypeDef",
-    "ListPresetsResponseResponseTypeDef",
+    "ListJobsByPipelineRequestRequestTypeDef",
+    "ListJobsByPipelineResponseTypeDef",
+    "ListJobsByStatusRequestRequestTypeDef",
+    "ListJobsByStatusResponseTypeDef",
+    "ListPipelinesRequestRequestTypeDef",
+    "ListPipelinesResponseTypeDef",
+    "ListPresetsRequestRequestTypeDef",
+    "ListPresetsResponseTypeDef",
     "NotificationsTypeDef",
     "PaginatorConfigTypeDef",
     "PermissionTypeDef",
@@ -65,24 +65,24 @@ __all__ = (
     "PlaylistTypeDef",
     "PresetTypeDef",
     "PresetWatermarkTypeDef",
-    "ReadJobRequestTypeDef",
-    "ReadJobResponseResponseTypeDef",
-    "ReadPipelineRequestTypeDef",
-    "ReadPipelineResponseResponseTypeDef",
-    "ReadPresetRequestTypeDef",
-    "ReadPresetResponseResponseTypeDef",
+    "ReadJobRequestRequestTypeDef",
+    "ReadJobResponseTypeDef",
+    "ReadPipelineRequestRequestTypeDef",
+    "ReadPipelineResponseTypeDef",
+    "ReadPresetRequestRequestTypeDef",
+    "ReadPresetResponseTypeDef",
     "ResponseMetadataTypeDef",
-    "TestRoleRequestTypeDef",
-    "TestRoleResponseResponseTypeDef",
+    "TestRoleRequestRequestTypeDef",
+    "TestRoleResponseTypeDef",
     "ThumbnailsTypeDef",
     "TimeSpanTypeDef",
     "TimingTypeDef",
-    "UpdatePipelineNotificationsRequestTypeDef",
-    "UpdatePipelineNotificationsResponseResponseTypeDef",
-    "UpdatePipelineRequestTypeDef",
-    "UpdatePipelineResponseResponseTypeDef",
-    "UpdatePipelineStatusRequestTypeDef",
-    "UpdatePipelineStatusResponseResponseTypeDef",
+    "UpdatePipelineNotificationsRequestRequestTypeDef",
+    "UpdatePipelineNotificationsResponseTypeDef",
+    "UpdatePipelineRequestRequestTypeDef",
+    "UpdatePipelineResponseTypeDef",
+    "UpdatePipelineStatusRequestRequestTypeDef",
+    "UpdatePipelineStatusResponseTypeDef",
     "VideoParametersTypeDef",
     "WaiterConfigTypeDef",
     "WarningTypeDef",
@@ -126,8 +126,8 @@ AudioParametersTypeDef = TypedDict(
     total=False,
 )
 
-CancelJobRequestTypeDef = TypedDict(
-    "CancelJobRequestTypeDef",
+CancelJobRequestRequestTypeDef = TypedDict(
+    "CancelJobRequestRequestTypeDef",
     {
         "Id": str,
     },
@@ -203,14 +203,14 @@ CreateJobPlaylistTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCreateJobRequestTypeDef = TypedDict(
-    "_RequiredCreateJobRequestTypeDef",
+_RequiredCreateJobRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateJobRequestRequestTypeDef",
     {
         "PipelineId": str,
     },
 )
-_OptionalCreateJobRequestTypeDef = TypedDict(
-    "_OptionalCreateJobRequestTypeDef",
+_OptionalCreateJobRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateJobRequestRequestTypeDef",
     {
         "Input": "JobInputTypeDef",
         "Inputs": List["JobInputTypeDef"],
@@ -224,28 +224,30 @@ _OptionalCreateJobRequestTypeDef = TypedDict(
 )
 
 
-class CreateJobRequestTypeDef(_RequiredCreateJobRequestTypeDef, _OptionalCreateJobRequestTypeDef):
+class CreateJobRequestRequestTypeDef(
+    _RequiredCreateJobRequestRequestTypeDef, _OptionalCreateJobRequestRequestTypeDef
+):
     pass
 
 
-CreateJobResponseResponseTypeDef = TypedDict(
-    "CreateJobResponseResponseTypeDef",
+CreateJobResponseTypeDef = TypedDict(
+    "CreateJobResponseTypeDef",
     {
         "Job": "JobTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreatePipelineRequestTypeDef = TypedDict(
-    "_RequiredCreatePipelineRequestTypeDef",
+_RequiredCreatePipelineRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePipelineRequestRequestTypeDef",
     {
         "Name": str,
         "InputBucket": str,
         "Role": str,
     },
 )
-_OptionalCreatePipelineRequestTypeDef = TypedDict(
-    "_OptionalCreatePipelineRequestTypeDef",
+_OptionalCreatePipelineRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePipelineRequestRequestTypeDef",
     {
         "OutputBucket": str,
         "AwsKmsKeyArn": str,
@@ -257,14 +259,14 @@ _OptionalCreatePipelineRequestTypeDef = TypedDict(
 )
 
 
-class CreatePipelineRequestTypeDef(
-    _RequiredCreatePipelineRequestTypeDef, _OptionalCreatePipelineRequestTypeDef
+class CreatePipelineRequestRequestTypeDef(
+    _RequiredCreatePipelineRequestRequestTypeDef, _OptionalCreatePipelineRequestRequestTypeDef
 ):
     pass
 
 
-CreatePipelineResponseResponseTypeDef = TypedDict(
-    "CreatePipelineResponseResponseTypeDef",
+CreatePipelineResponseTypeDef = TypedDict(
+    "CreatePipelineResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
         "Warnings": List["WarningTypeDef"],
@@ -272,15 +274,15 @@ CreatePipelineResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreatePresetRequestTypeDef = TypedDict(
-    "_RequiredCreatePresetRequestTypeDef",
+_RequiredCreatePresetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePresetRequestRequestTypeDef",
     {
         "Name": str,
         "Container": str,
     },
 )
-_OptionalCreatePresetRequestTypeDef = TypedDict(
-    "_OptionalCreatePresetRequestTypeDef",
+_OptionalCreatePresetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePresetRequestRequestTypeDef",
     {
         "Description": str,
         "Video": "VideoParametersTypeDef",
@@ -291,14 +293,14 @@ _OptionalCreatePresetRequestTypeDef = TypedDict(
 )
 
 
-class CreatePresetRequestTypeDef(
-    _RequiredCreatePresetRequestTypeDef, _OptionalCreatePresetRequestTypeDef
+class CreatePresetRequestRequestTypeDef(
+    _RequiredCreatePresetRequestRequestTypeDef, _OptionalCreatePresetRequestRequestTypeDef
 ):
     pass
 
 
-CreatePresetResponseResponseTypeDef = TypedDict(
-    "CreatePresetResponseResponseTypeDef",
+CreatePresetResponseTypeDef = TypedDict(
+    "CreatePresetResponseTypeDef",
     {
         "Preset": "PresetTypeDef",
         "Warning": str,
@@ -306,15 +308,15 @@ CreatePresetResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeletePipelineRequestTypeDef = TypedDict(
-    "DeletePipelineRequestTypeDef",
+DeletePipelineRequestRequestTypeDef = TypedDict(
+    "DeletePipelineRequestRequestTypeDef",
     {
         "Id": str,
     },
 )
 
-DeletePresetRequestTypeDef = TypedDict(
-    "DeletePresetRequestTypeDef",
+DeletePresetRequestRequestTypeDef = TypedDict(
+    "DeletePresetRequestRequestTypeDef",
     {
         "Id": str,
     },
@@ -448,14 +450,14 @@ JobWatermarkTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListJobsByPipelineRequestTypeDef = TypedDict(
-    "_RequiredListJobsByPipelineRequestTypeDef",
+_RequiredListJobsByPipelineRequestRequestTypeDef = TypedDict(
+    "_RequiredListJobsByPipelineRequestRequestTypeDef",
     {
         "PipelineId": str,
     },
 )
-_OptionalListJobsByPipelineRequestTypeDef = TypedDict(
-    "_OptionalListJobsByPipelineRequestTypeDef",
+_OptionalListJobsByPipelineRequestRequestTypeDef = TypedDict(
+    "_OptionalListJobsByPipelineRequestRequestTypeDef",
     {
         "Ascending": str,
         "PageToken": str,
@@ -464,14 +466,15 @@ _OptionalListJobsByPipelineRequestTypeDef = TypedDict(
 )
 
 
-class ListJobsByPipelineRequestTypeDef(
-    _RequiredListJobsByPipelineRequestTypeDef, _OptionalListJobsByPipelineRequestTypeDef
+class ListJobsByPipelineRequestRequestTypeDef(
+    _RequiredListJobsByPipelineRequestRequestTypeDef,
+    _OptionalListJobsByPipelineRequestRequestTypeDef,
 ):
     pass
 
 
-ListJobsByPipelineResponseResponseTypeDef = TypedDict(
-    "ListJobsByPipelineResponseResponseTypeDef",
+ListJobsByPipelineResponseTypeDef = TypedDict(
+    "ListJobsByPipelineResponseTypeDef",
     {
         "Jobs": List["JobTypeDef"],
         "NextPageToken": str,
@@ -479,14 +482,14 @@ ListJobsByPipelineResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListJobsByStatusRequestTypeDef = TypedDict(
-    "_RequiredListJobsByStatusRequestTypeDef",
+_RequiredListJobsByStatusRequestRequestTypeDef = TypedDict(
+    "_RequiredListJobsByStatusRequestRequestTypeDef",
     {
         "Status": str,
     },
 )
-_OptionalListJobsByStatusRequestTypeDef = TypedDict(
-    "_OptionalListJobsByStatusRequestTypeDef",
+_OptionalListJobsByStatusRequestRequestTypeDef = TypedDict(
+    "_OptionalListJobsByStatusRequestRequestTypeDef",
     {
         "Ascending": str,
         "PageToken": str,
@@ -495,14 +498,14 @@ _OptionalListJobsByStatusRequestTypeDef = TypedDict(
 )
 
 
-class ListJobsByStatusRequestTypeDef(
-    _RequiredListJobsByStatusRequestTypeDef, _OptionalListJobsByStatusRequestTypeDef
+class ListJobsByStatusRequestRequestTypeDef(
+    _RequiredListJobsByStatusRequestRequestTypeDef, _OptionalListJobsByStatusRequestRequestTypeDef
 ):
     pass
 
 
-ListJobsByStatusResponseResponseTypeDef = TypedDict(
-    "ListJobsByStatusResponseResponseTypeDef",
+ListJobsByStatusResponseTypeDef = TypedDict(
+    "ListJobsByStatusResponseTypeDef",
     {
         "Jobs": List["JobTypeDef"],
         "NextPageToken": str,
@@ -510,8 +513,8 @@ ListJobsByStatusResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListPipelinesRequestTypeDef = TypedDict(
-    "ListPipelinesRequestTypeDef",
+ListPipelinesRequestRequestTypeDef = TypedDict(
+    "ListPipelinesRequestRequestTypeDef",
     {
         "Ascending": str,
         "PageToken": str,
@@ -519,8 +522,8 @@ ListPipelinesRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListPipelinesResponseResponseTypeDef = TypedDict(
-    "ListPipelinesResponseResponseTypeDef",
+ListPipelinesResponseTypeDef = TypedDict(
+    "ListPipelinesResponseTypeDef",
     {
         "Pipelines": List["PipelineTypeDef"],
         "NextPageToken": str,
@@ -528,8 +531,8 @@ ListPipelinesResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListPresetsRequestTypeDef = TypedDict(
-    "ListPresetsRequestTypeDef",
+ListPresetsRequestRequestTypeDef = TypedDict(
+    "ListPresetsRequestRequestTypeDef",
     {
         "Ascending": str,
         "PageToken": str,
@@ -537,8 +540,8 @@ ListPresetsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListPresetsResponseResponseTypeDef = TypedDict(
-    "ListPresetsResponseResponseTypeDef",
+ListPresetsResponseTypeDef = TypedDict(
+    "ListPresetsResponseTypeDef",
     {
         "Presets": List["PresetTypeDef"],
         "NextPageToken": str,
@@ -665,30 +668,30 @@ PresetWatermarkTypeDef = TypedDict(
     total=False,
 )
 
-ReadJobRequestTypeDef = TypedDict(
-    "ReadJobRequestTypeDef",
+ReadJobRequestRequestTypeDef = TypedDict(
+    "ReadJobRequestRequestTypeDef",
     {
         "Id": str,
     },
 )
 
-ReadJobResponseResponseTypeDef = TypedDict(
-    "ReadJobResponseResponseTypeDef",
+ReadJobResponseTypeDef = TypedDict(
+    "ReadJobResponseTypeDef",
     {
         "Job": "JobTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-ReadPipelineRequestTypeDef = TypedDict(
-    "ReadPipelineRequestTypeDef",
+ReadPipelineRequestRequestTypeDef = TypedDict(
+    "ReadPipelineRequestRequestTypeDef",
     {
         "Id": str,
     },
 )
 
-ReadPipelineResponseResponseTypeDef = TypedDict(
-    "ReadPipelineResponseResponseTypeDef",
+ReadPipelineResponseTypeDef = TypedDict(
+    "ReadPipelineResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
         "Warnings": List["WarningTypeDef"],
@@ -696,15 +699,15 @@ ReadPipelineResponseResponseTypeDef = TypedDict(
     },
 )
 
-ReadPresetRequestTypeDef = TypedDict(
-    "ReadPresetRequestTypeDef",
+ReadPresetRequestRequestTypeDef = TypedDict(
+    "ReadPresetRequestRequestTypeDef",
     {
         "Id": str,
     },
 )
 
-ReadPresetResponseResponseTypeDef = TypedDict(
-    "ReadPresetResponseResponseTypeDef",
+ReadPresetResponseTypeDef = TypedDict(
+    "ReadPresetResponseTypeDef",
     {
         "Preset": "PresetTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -722,8 +725,8 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-TestRoleRequestTypeDef = TypedDict(
-    "TestRoleRequestTypeDef",
+TestRoleRequestRequestTypeDef = TypedDict(
+    "TestRoleRequestRequestTypeDef",
     {
         "Role": str,
         "InputBucket": str,
@@ -732,8 +735,8 @@ TestRoleRequestTypeDef = TypedDict(
     },
 )
 
-TestRoleResponseResponseTypeDef = TypedDict(
-    "TestRoleResponseResponseTypeDef",
+TestRoleResponseTypeDef = TypedDict(
+    "TestRoleResponseTypeDef",
     {
         "Success": str,
         "Messages": List[str],
@@ -775,30 +778,30 @@ TimingTypeDef = TypedDict(
     total=False,
 )
 
-UpdatePipelineNotificationsRequestTypeDef = TypedDict(
-    "UpdatePipelineNotificationsRequestTypeDef",
+UpdatePipelineNotificationsRequestRequestTypeDef = TypedDict(
+    "UpdatePipelineNotificationsRequestRequestTypeDef",
     {
         "Id": str,
         "Notifications": "NotificationsTypeDef",
     },
 )
 
-UpdatePipelineNotificationsResponseResponseTypeDef = TypedDict(
-    "UpdatePipelineNotificationsResponseResponseTypeDef",
+UpdatePipelineNotificationsResponseTypeDef = TypedDict(
+    "UpdatePipelineNotificationsResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredUpdatePipelineRequestTypeDef = TypedDict(
-    "_RequiredUpdatePipelineRequestTypeDef",
+_RequiredUpdatePipelineRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdatePipelineRequestRequestTypeDef",
     {
         "Id": str,
     },
 )
-_OptionalUpdatePipelineRequestTypeDef = TypedDict(
-    "_OptionalUpdatePipelineRequestTypeDef",
+_OptionalUpdatePipelineRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdatePipelineRequestRequestTypeDef",
     {
         "Name": str,
         "InputBucket": str,
@@ -812,14 +815,14 @@ _OptionalUpdatePipelineRequestTypeDef = TypedDict(
 )
 
 
-class UpdatePipelineRequestTypeDef(
-    _RequiredUpdatePipelineRequestTypeDef, _OptionalUpdatePipelineRequestTypeDef
+class UpdatePipelineRequestRequestTypeDef(
+    _RequiredUpdatePipelineRequestRequestTypeDef, _OptionalUpdatePipelineRequestRequestTypeDef
 ):
     pass
 
 
-UpdatePipelineResponseResponseTypeDef = TypedDict(
-    "UpdatePipelineResponseResponseTypeDef",
+UpdatePipelineResponseTypeDef = TypedDict(
+    "UpdatePipelineResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
         "Warnings": List["WarningTypeDef"],
@@ -827,16 +830,16 @@ UpdatePipelineResponseResponseTypeDef = TypedDict(
     },
 )
 
-UpdatePipelineStatusRequestTypeDef = TypedDict(
-    "UpdatePipelineStatusRequestTypeDef",
+UpdatePipelineStatusRequestRequestTypeDef = TypedDict(
+    "UpdatePipelineStatusRequestRequestTypeDef",
     {
         "Id": str,
         "Status": str,
     },
 )
 
-UpdatePipelineStatusResponseResponseTypeDef = TypedDict(
-    "UpdatePipelineStatusResponseResponseTypeDef",
+UpdatePipelineStatusResponseTypeDef = TypedDict(
+    "UpdatePipelineStatusResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
